---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:1970-05-20;300
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=19700527&codiceRedaz=070U0300&dataVigenza=20251104
dataGU: 19700527
codiceRedaz: 070U0300
dataVigenza: 20251104
---

# Norme sulla tutela della liberta' e dignita' dei lavoratori, della liberta' sindacale e dell'attivita' sindacale, nei luoghi di lavoro e norme sul collocamento.

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

PROMULGA la seguente legge:

## DELLA LIBERTA' E DIGNITA' DEL LAVORATORE

### Art. 1. - (Liberta' di opinione)

I lavoratori, senza distinzione di opinioni politiche, sindacali e di fede religiosa, hanno diritto, nei luoghi dove prestano la loro opera, di manifestare liberamente il proprio pensiero, nel rispetto dei principi della Costituzione e delle norme della presente legge.

### Art. 2. - (Guardie giurate)

Il datore di lavoro puo' impiegare le guardie particolari giurate, di cui agli articoli 133 e seguenti del testo unico approvato con regio decreto 18 giugno 1931, n. 773, soltanto per scopi di tutela del patrimonio aziendale. Le guardie giurate non possono contestare ai lavoratori azioni o fatti diversi da quelli che attengono alla tutela del patrimonio aziendale. E' fatto divieto al datore di lavoro di adibire alla vigilanza sull'attivita' lavorativa le guardie di cui al primo comma, le quali non possono accedere nei locali dove si svolge tale attivita', durante lo svolgimento della stessa, se non eccezionalmente per specifiche e motivate esigenze attinenti ai compiti di cui al primo comma, in caso di inosservanza da parte di una guardia particolare giurata delle disposizioni di cui al presente articolo, l'Ispettorato del lavoro ne promuove presso il questore la sospensione dal servizio, salvo il provvedimento di revoca della licenza da parte del prefetto nei casi piu' gravi.

### Art. 3. - (Personale di vigilanza)

I nominativi e le mansioni specifiche del personale addetto alla vigilanza dell'attivita' lavorativa debbono essere comunicati ai lavoratori interessati.

### Art. 4. - (Impianti audiovisivi e altri strumenti di controllo)

1. Gli impianti audiovisivi e gli altri strumenti dai quali derivi anche la possibilita' di controllo a distanza dell'attivita' dei lavoratori possono essere impiegati esclusivamente per esigenze organizzative e produttive, per la sicurezza del lavoro e per la tutela del patrimonio aziendale e possono essere installati previo accordo collettivo stipulato dalla rappresentanza sindacale unitaria o dalle rappresentanze sindacali aziendali. In alternativa, nel caso di imprese con unita' produttive ubicate in diverse province della stessa regione ovvero in piu' regioni, tale accordo puo' essere stipulato dalle associazioni sindacali comparativamente piu' rappresentative sul piano nazionale. ((In mancanza di accordo, gli impianti e gli strumenti di cui al primo periodo possono essere installati previa autorizzazione delle sede territoriale dell'Ispettorato nazionale del lavoro o, in alternativa, nel caso di imprese con unita' produttive dislocate negli ambiti di competenza di piu' sedi territoriali, della sede centrale dell'Ispettorato nazionale del lavoro. I provvedimenti di cui al terzo periodo sono definitivi.))

2. La disposizione di cui al comma 1 non si applica agli strumenti utilizzati dal lavoratore per rendere la prestazione lavorativa e agli strumenti di registrazione degli accessi e delle presenze.

3. Le informazioni raccolte ai sensi dei commi 1 e 2 sono utilizzabili a tutti i fini connessi al rapporto di lavoro a condizione che sia data al lavoratore adeguata informazione delle modalita' d'uso degli strumenti e di effettuazione dei controlli e nel rispetto di quanto disposto dal decreto legislativo 30 giugno 2003, n. 196.

### Art. 5. - (Accertamenti sanitari)

Sono vietati accertamenti da parte del datore di lavoro sulla idoneita' e sulla infermita' per malattia o infortunio del lavoratore dipendente. Il controllo delle assenze per infermita' puo' essere effettuato soltanto attraverso i servizi ispettivi degli istituti previdenziali competenti, i quali sono tenuti a compierlo quando il datore di lavoro lo richieda. Il datore di lavoro ha facolta' di far controllare la idoneita' fisica del lavoratore da parte di enti pubblici ed istituti specializzati di diritto pubblico.

### Art. 6. - (Visite personali di controllo)

Le visite personali di controllo sul lavoratore sono vietate fuorche' nei casi in cui siano indispensabili ai fini della tutela del patrimonio aziendale, in relazione alla qualita' degli strumenti di lavoro o delle materie prime o dei prodotti. In tali casi le visite personali potranno essere effettuate soltanto a condizione che siano eseguite all'uscita dei luoghi di lavoro, che siano salvaguardate la dignita' e la riservatezza del lavoratore e che avvengano con l'applicazione di sistemi di selezione automatica riferiti alla collettivita' o a gruppi di lavoratori. Le ipotesi nelle quali possono essere disposte le visite personali, nonche', ferme restando le condizioni di cui al secondo comma del presente articolo, le relative modalita' debbono essere concordate dal datore di lavoro con le rappresentanze sindacali aziendali oppure, in mancanza di queste, con la commissione interna. In difetto di accordo, su istanza del datore di lavoro, provvede l'Ispettorato del lavoro. Contro i provvedimenti dell'Ispettorato del lavoro di cui al precedente comma, il datore di lavoro, le rappresentanze sindacali aziendali o, in mancanza di queste, la commissione interna, oppure i sindacati dei lavoratori di cui al successivo articolo 19 possono ricorrere, entro 30 giorni dalla comunicazione del provvedimento, al Ministro per il lavoro e la previdenza sociale.

### Art. 7. - (Sanzioni disciplinari)

Le norme disciplinari relative alle sanzioni, alle infrazioni in relazione alle quali ciascuna di esse puo' essere applicata ed alle procedure di contestazione delle stesse, devono essere portate a conoscenza dei lavoratori mediante affissione in luogo accessibile a tutti. Esse devono applicare quanto in materia e' stabilito da accordi e contratti di lavoro ove esistano. (5) Il datore di lavoro non puo' adottare alcun provvedimento disciplinare nei confronti del lavoratore senza avergli preventivamente contestato l'addebito e senza averlo sentito a sua difesa. (5) (8) Il lavoratore potra' farsi assistere da un rappresentante dell'associazione sindacale cui aderisce o conferisce mandato. (5) (8) Fermo restando quanto disposto dalla legge 15 luglio 1966, n. 604, non possono essere disposte sanzioni disciplinari che comportino mutamenti definitivi del rapporto di lavoro; inoltre la multa non puo' essere disposta per un importo superiore a quattro ore della retribuzione base e la sospensione dal servizio e dalla retribuzione per piu' di dieci giorni. In ogni caso, i provvedimenti disciplinari piu' gravi del rimprovero verbale, non possono essere applicati prima che siano trascorsi cinque giorni dalla contestazione per iscritto del fatto che vi ha dato causa. Salvo analoghe procedure previste dai contratti collettivi di lavoro e ferma restando la facolta' di adire l'autorita' giudiziaria, il lavoratore al quale sia stata applicata una sanzione disciplinare puo' promuovere, nei venti giorni successivi, anche per mezzo dell'associazione alla quale sia iscritto ovvero conferisca mandato, la costituzione, tramite l'ufficio provinciale del lavoro e della massima occupazione, di un collegio di conciliazione ed arbitrato, composto da un rappresentante di ciascuna delle parti e da un terzo membro scelto di comune accordo o, in difetto di accordo, nominato dal direttore dell'ufficio del lavoro. La sanzione disciplinare resta sospesa fino alla pronuncia da parte del collegio. Qualora il datore di lavoro non provveda, entro dieci giorni dall'invito rivoltogli dall'ufficio del lavoro, a nominare il proprio rappresentante in seno al collegio di cui al comma precedente, la sanzione disciplinare non ha effetto. Se il datore di lavoro adisce l'autorita' giudiziaria, la sanzione disciplinare resta sospesa fino alla definizione del giudizio. Non puo' tenersi conto ad alcun effetto delle sanzioni disciplinari decorsi due anni dalla loro applicazione. ((24))

--------------- AGGIORNAMENTO (5) La Corte Costituzionale, con sentenza del 29-30 novembre 1982, n. 204 (in G.U. 1a s.s. 09/12/1982, n. 338), ha dichiarato "l'illegittimita' costituzionale dei commi primo, secondo e terzo dell'art. 7 (sanzioni disciplinari) l. 20 maggio 1970, n. 300 (norme sulla tutela della liberta' e dignita' dei lavoratori, della liberta' sindacale e dell'attivita' sindacale nei luoghi di lavoro e norme sul collocamento), interpretati nel senso che siano inapplicabili ai licenziamenti disciplinari, per i quali detti commi non siano espressamente richiamati dalla normativa legislativa, collettiva o validamente posta dal datore di lavoro". --------------- AGGIORNAMENTO (8) La Corte Costituzionale, con sentenza del 18-25 luglio 1989, n. 427 (in G.U. 1a s.s. 02/08/1989, n. 31), ha dichiarato "la illegittimita' costituzionale dell'art. 7, secondo e terzo comma, della legge 20 maggio 1970, n. 300 (Norme sulla tutela della liberta' e dignita' dei lavoratori, della liberta' sindacale e dell'attivita' sindacale nei luoghi di lavoro e norme sul collocamento), nella parte in cui e' esclusa la loro applicabilita' al licenziamento per motivi disciplinari irrogato da imprenditore che abbia meno di sedici dipendenti". --------------- AGGIORNAMENTO (24) La L. 28 giugno 2012, n. 92, ha disposto (con l'art. 1, comma 41) che "Il licenziamento intimato all'esito del procedimento disciplinare di cui all'articolo 7 della legge 20 maggio 1970, n. 300, oppure all'esito del procedimento di cui all'articolo 7 della legge 15 luglio 1966, n. 604, come sostituito dal comma 40 del presente articolo, produce effetto dal giorno della comunicazione con cui il procedimento medesimo e' stato avviato, salvo l'eventuale diritto del lavoratore al preavviso o alla relativa indennita' sostitutiva; e' fatto salvo, in ogni caso, l'effetto sospensivo disposto dalle norme del testo unico delle disposizioni legislative in materia di tutela della maternita' e della paternita', di cui al decreto legislativo 26 marzo 2001, n. 151. Gli effetti rimangono altresi' sospesi in caso di impedimento derivante da infortunio occorso sul lavoro. Il periodo di eventuale lavoro svolto in costanza della procedura si considera come preavviso lavorato".

### Art. 8. - (Divieto di indagini sulle opinioni)

E' fatto divieto al datore di lavoro, ai fini dell'assunzione, come nel corso dello svolgimento del rapporto di lavoro, di effettuare indagini, anche a mezzo di terzi, sulle opinioni politiche, religiose o sindacali del lavoratore, nonche' su fatti non rilevanti ai fini della valutazione dell'attitudine professionale del lavoratore.

### Art. 9. - (Tutela della salute e dell'integrita' fisica)

I lavoratori, mediante loro rappresentanze, hanno diritto di controllare l'applicazione delle norme per la prevenzione degli infortuni e delle malattie professionali e di promuovere la ricerca, l'elaborazione e l'attuazione di tutte le misure idonee a tutelare la loro salute e la loro integrita' fisica.

### Art. 10. - (Lavoratori studenti)

I lavoratori studenti, iscritti e frequentanti corsi regolari di studio in scuole di istruzione primaria, secondaria e di qualificazione professionale, statali, pareggiate o legalmente riconosciute o comunque abilitate al rilascio di titoli di studio legali, hanno diritto a turni di lavoro che agevolino la frequenza ai corsi e la preparazione agli esami e non sono obbligati a prestazioni di lavoro straordinario o durante i riposi settimanali. I lavoratori studenti, compresi quelli universitari, che devono sostenere prove di esame, hanno diritto a fruire di permessi giornalieri retribuiti. Il datore di lavoro potra' richiedere la produzione delle certificazioni necessarie all'esercizio dei diritti di cui al primo e secondo comma.

### Art. 11.

( Attivita' culturali, ricreative e assistenziali ((e controlli sul servizio di mensa)) ) Le attivita' culturali, ricreative ed assistenziali promosse nell'azienda sono gestite da organismi formati a maggioranza dai rappresentanti dei lavoratori. ((Le rappresentanze sindacali aziendali, costituite a norma dell'articolo 19, hanno diritto di controllare la qualita' del servizio di mensa secondo modalita' stabilite dalla contrattazione collettiva)).

### Art. 12. - (Istituti di patronato)

Gli istituti di patronato e di assistenza sociale, riconosciuti dal Ministero del lavoro e della previdenza sociale, per l'adempimento dei compiti di cui al decreto legislativo del Capo provvisorio dello Stato 29 luglio 1947, n. 804, hanno diritto di svolgere, su un piano di parita', la loro attivita' all'interno dell'azienda, secondo le modalita' da stabilirsi con accordi aziendali.

### Art. 13. - (Mansioni del lavoratore)

L'articolo 2103 del codice civile e' sostituito dal seguente: "Il prestatore di lavoro deve essere adibito alle mansioni per le quali e' stato assunto o a quelle corrispondenti alla categoria superiore che abbia successivamente acquisito ovvero a mansioni equivalenti alle ultime effettivamente svolte, senza alcuna diminuzione della retribuzione. Nel caso di assegnazione a mansioni superiori il prestatore ha diritto al trattamento corrispondente all'attivita' svolta, e l'assegnazione stessa diviene definitiva, ove la medesima non abbia avuto luogo per sostituzione di lavoratore assente con diritto alla conservazione del posto, dopo un periodo fissato dai contratti collettivi, e comunque non superiore a tre mesi. Egli non puo' essere trasferito da una unita' produttiva ad un'altra se non per comprovate ragioni tecniche, organizzative e produttive. Ogni patto contrario e' nullo".

## DELLA LIBERTA' SINDACALE

### Art. 14. - (Diritto di associazione e di attivita' sindacale)

Il diritto di costituire associazioni sindacali, di aderirvi e di svolgere attivita' sindacale, e' garantito a tutti i lavoratori all'interno dei luoghi di lavoro.

### Art. 15. - (Atti discriminatori)

E' nullo qualsiasi patto od atto diretto a: a) subordinare l'occupazione di un lavoratore alla condizione che aderisca o non aderisca ad una associazione sindacale ovvero cessi di farne parte; b) licenziare un lavoratore, discriminarlo nella assegnazione di qualifiche o mansioni, nei trasferimenti, nei provvedimenti disciplinari, o recargli altrimenti pregiudizio a causa della sua affiliazione o attivita' sindacale ovvero della sua partecipazione ad uno sciopero. Le disposizioni di cui al comma precedente si applicano altresi' ai patti o atti diretti a fini di discriminazione politica, religiosa, razziale, di lingua o di sesso, di handicap, di eta' ((, di nazionalita')) o basata sull'orientamento sessuale o sulle convinzioni personali.

### Art. 16. - (Trattamenti economici collettivi discriminatori)

E' vietata la concessione di trattamenti economici di maggior favore aventi carattere discriminatorio a mente dell'articolo 15. Il pretore, su domanda dei lavoratori nei cui confronti e' stata attuata la discriminazione di cui al comma precedente o delle associazioni sindacali alle quali questi hanno dato mandato, accertati i fatti, condanna il datore di lavoro al pagamento, a favore del fondo adeguamento pensioni, di una somma pari all'importo dei trattamenti economici di maggior favore illegittimamente corrisposti nel periodo massimo di un anno.

### Art. 17. - (Sindacati di comodo)

E' fatto divieto ai datori di lavoro e alle associazioni di datori di lavoro di costituire o sostenere, con mezzi finanziari o altrimenti, associazioni sindacali di lavoratori.

### Art. 18. - Tutela del lavoratore in caso di licenziamento illegittimo

Il giudice, con la sentenza con la quale dichiara la nullita' del licenziamento perche' discriminatorio ai sensi dell'articolo 3 della legge 11 maggio 1990, n. 108, ovvero intimato in concomitanza col matrimonio ai sensi dell'articolo 35 del codice delle pari opportunita' tra uomo e donna, di cui al decreto legislativo 11 aprile 2006, n. 198, o in violazione dei divieti di licenziamento di cui all'articolo 54, commi 1, 6, 7 e 9, del testo unico delle disposizioni legislative in materia di tutela e sostegno della maternita' e della paternita', di cui al decreto legislativo 26 marzo 2001, n. 151, e successive modificazioni, ovvero perche' riconducibile ad altri casi di nullita' previsti dalla legge o determinato da un motivo illecito determinante ai sensi dell'articolo 1345 del codice civile, ordina al datore di lavoro, imprenditore o non imprenditore, la reintegrazione del lavoratore nel posto di lavoro, indipendentemente dal motivo formalmente addotto e quale che sia il numero dei dipendenti occupati dal datore di lavoro. La presente disposizione si applica anche ai dirigenti. A seguito dell'ordine di reintegrazione, il rapporto di lavoro si intende risolto quando il lavoratore non abbia ripreso servizio entro trenta giorni dall'invito del datore di lavoro, salvo il caso in cui abbia richiesto l'indennita' di cui al terzo comma del presente articolo. Il regime di cui al presente articolo si applica anche al licenziamento dichiarato inefficace perche' intimato in forma orale. Il giudice, con la sentenza di cui al primo comma, condanna altresi' il datore di lavoro al risarcimento del danno subito dal lavoratore per il licenziamento di cui sia stata accertata la nullita', stabilendo a tal fine un'indennita' commisurata all'ultima retribuzione globale di fatto maturata dal giorno del licenziamento sino a quello dell'effettiva reintegrazione, dedotto quanto percepito, nel periodo di estromissione, per lo svolgimento di altre attivita' lavorative. In ogni caso la misura del risarcimento non potra' essere inferiore a cinque mensilita' della retribuzione globale di fatto. Il datore di lavoro e' condannato inoltre, per il medesimo periodo, al versamento dei contributi previdenziali e assistenziali. Fermo restando il diritto al risarcimento del danno come previsto al secondo comma, al lavoratore e' data la facolta' di chiedere al datore di lavoro, in sostituzione della reintegrazione nel posto di lavoro, un'indennita' pari a quindici mensilita' dell'ultima retribuzione globale di fatto, la cui richiesta determina la risoluzione del rapporto di lavoro, e che non e' assoggettata a contribuzione previdenziale. La richiesta dell'indennita' deve essere effettuata entro trenta giorni dalla comunicazione del deposito della sentenza, o dall'invito del datore di lavoro a riprendere servizio, se anteriore alla predetta comunicazione. Il giudice, nelle ipotesi in cui accerta che non ricorrono gli estremi del giustificato motivo soggettivo o della giusta causa addotti dal datore di lavoro, per insussistenza del fatto contestato ovvero perche' il fatto rientra tra le condotte punibili con una sanzione conservativa sulla base delle previsioni dei contratti collettivi ovvero dei codici disciplinari applicabili, annulla il licenziamento e condanna il datore di lavoro alla reintegrazione nel posto di lavoro di cui al primo comma e al pagamento di un'indennita' risarcitoria commisurata all'ultima retribuzione globale di fatto dal giorno del licenziamento sino a quello dell'effettiva reintegrazione, dedotto quanto il lavoratore ha percepito, nel periodo di estromissione, per lo svolgimento di altre attivita' lavorative, nonche' quanto avrebbe potuto percepire dedicandosi con diligenza alla ricerca di una nuova occupazione. In ogni caso la misura dell'indennita' risarcitoria non puo' essere superiore a dodici mensilita' della retribuzione globale di fatto. Il datore di lavoro e' condannato, altresi', al versamento dei contributi previdenziali e assistenziali dal giorno del licenziamento fino a quello della effettiva reintegrazione, maggiorati degli interessi nella misura legale senza applicazione di sanzioni per omessa o ritardata contribuzione, per un importo pari al differenziale contributivo esistente tra la contribuzione che sarebbe stata maturata nel rapporto di lavoro risolto dall'illegittimo licenziamento e quella accreditata al lavoratore in conseguenza dello svolgimento di altre attivita' lavorative. In quest'ultimo caso, qualora i contributi afferiscano ad altra gestione previdenziale, essi sono imputati d'ufficio alla gestione corrispondente all'attivita' lavorativa svolta dal dipendente licenziato, con addebito dei relativi costi al datore di lavoro. A seguito dell'ordine di reintegrazione, il rapporto di lavoro si intende risolto quando il lavoratore non abbia ripreso servizio entro trenta giorni dall'invito del datore di lavoro, salvo il caso in cui abbia richiesto l'indennita' sostitutiva della reintegrazione nel posto di lavoro ai sensi del terzo comma. Il giudice, nelle altre ipotesi in cui accerta che non ricorrono gli estremi del giustificato motivo soggettivo o della giusta causa addotti dal datore di lavoro, dichiara risolto il rapporto di lavoro con effetto dalla data del licenziamento e condanna il datore di lavoro al pagamento di un'indennita' risarcitoria onnicomprensiva determinata tra un minimo di dodici e un massimo di ventiquattro mensilita' dell'ultima retribuzione globale di fatto, in relazione all'anzianita' del lavoratore e tenuto conto del numero dei dipendenti occupati, delle dimensioni dell'attivita' economica, del comportamento e delle condizioni delle parti, con onere di specifica motivazione a tale riguardo. Nell'ipotesi in cui il licenziamento sia dichiarato inefficace per violazione del requisito di motivazione di cui all'articolo 2, comma 2, della legge 15 luglio 1966, n. 604, e successive modificazioni, della procedura di cui all'articolo 7 della presente legge, o della procedura di cui all'articolo 7 della legge 15 luglio 1966, n. 604, e successive modificazioni, si applica il regime di cui al quinto comma, ma con attribuzione al lavoratore di un'indennita' risarcitoria onnicomprensiva determinata, in relazione alla gravita' della violazione formale o procedurale commessa dal datore di lavoro, tra un minimo di sei e un massimo di dodici mensilita' dell'ultima retribuzione globale di fatto, con onere di specifica motivazione a tale riguardo, a meno che il giudice, sulla base della domanda del lavoratore, accerti che vi e' anche un difetto di giustificazione del licenziamento, nel qual caso applica, in luogo di quelle previste dal presente comma, le tutele di cui ai commi quarto, quinto o settimo. Il giudice applica la medesima disciplina di cui al quarto comma del presente articolo nell'ipotesi in cui accerti il difetto di giustificazione del licenziamento intimato, anche ai sensi degli articoli 4, comma 4, e 10, comma 3, della legge 12 marzo 1999, n. 68, per motivo oggettivo consistente nell'inidoneita' fisica o psichica del lavoratore, ovvero che il licenziamento e' stato intimato in violazione dell'articolo 2110, secondo comma, del codice civile. Puo' altresi' applicare la predetta disciplina nell'ipotesi in cui accerti la manifesta insussistenza del fatto posto a base del licenziamento per giustificato motivo oggettivo; nelle altre ipotesi in cui accerta che non ricorrono gli estremi del predetto giustificato motivo, il giudice applica la disciplina di cui al quinto comma. In tale ultimo caso il giudice, ai fini della determinazione dell'indennita' tra il minimo e il massimo previsti, tiene conto, oltre ai criteri di cui al quinto comma, delle iniziative assunte dal lavoratore per la ricerca di una nuova occupazione e del comportamento delle parti nell'ambito della procedura di cui all'articolo 7 della legge 15 luglio 1966, n. 604, e successive modificazioni. Qualora, nel corso del giudizio, sulla base della domanda formulata dal lavoratore, il licenziamento risulti determinato da ragioni discriminatorie o disciplinari, trovano applicazione le relative tutele previste dal presente articolo. (28) ((30)) Le disposizioni dei commi dal quarto al settimo si applicano al datore di lavoro, imprenditore o non imprenditore, che in ciascuna sede, stabilimento, filiale, ufficio o reparto autonomo nel quale ha avuto luogo il licenziamento occupa alle sue dipendenze piu' di quindici lavoratori o piu' di cinque se si tratta di imprenditore agricolo, nonche' al datore di lavoro, imprenditore o non imprenditore, che nell'ambito dello stesso comune occupa piu' di quindici dipendenti e all'impresa agricola che nel medesimo ambito territoriale occupa piu' di cinque dipendenti, anche se ciascuna unita' produttiva, singolarmente considerata, non raggiunge tali limiti, e in ogni caso al datore di lavoro, imprenditore e non imprenditore, che occupa piu' di sessanta dipendenti. Ai fini del computo del numero dei dipendenti di cui all'ottavo comma si tiene conto dei lavoratori assunti con contratto a tempo indeterminato parziale per la quota di orario effettivamente svolto, tenendo conto, a tale proposito, che il computo delle unita' lavorative fa riferimento all'orario previsto dalla contrattazione collettiva del settore. Non si computano il coniuge e i parenti del datore di lavoro entro il secondo grado in linea diretta e in linea collaterale. Il computo dei limiti occupazionali di cui all'ottavo comma non incide su norme o istituti che prevedono agevolazioni finanziarie o creditizie. Nell'ipotesi di revoca del licenziamento, purche' effettuata entro il termine di quindici giorni dalla comunicazione al datore di lavoro dell'impugnazione del medesimo, il rapporto di lavoro si intende ripristinato senza soluzione di continuita', con diritto del lavoratore alla retribuzione maturata nel periodo precedente alla revoca, e non trovano applicazione i regimi sanzionatori previsti dal presente articolo. Nell'ipotesi di licenziamento dei lavoratori di cui all'articolo 22, su istanza congiunta del lavoratore e del sindacato cui questi aderisce o conferisca mandato, il giudice, in ogni stato e grado del giudizio di merito, puo' disporre con ordinanza, quando ritenga irrilevanti o insufficienti gli elementi di prova forniti dal datore di lavoro, la reintegrazione del lavoratore nel posto di lavoro. L'ordinanza di cui al comma precedente puo' essere impugnata con reclamo immediato al giudice medesimo che l'ha pronunciata. Si applicano le disposizioni dell'articolo 178, terzo, quarto, quinto e sesto comma del codice di procedura civile. L'ordinanza puo' essere revocata con la sentenza che decide la causa. Nell'ipotesi di licenziamento dei lavoratori di cui all'articolo 22, il datore di lavoro che non ottempera alla sentenza di cui al primo comma ovvero all'ordinanza di cui all'undicesimo comma, non impugnata o confermata dal giudice che l'ha pronunciata, e' tenuto anche, per ogni giorno di ritardo, al pagamento a favore del Fondo adeguamento pensioni di una somma pari all'importo della retribuzione dovuta al lavoratore. (9) (23)

--------------- AGGIORNAMENTO (9) La L. 11 maggio 1990, n. 108 ha disposto (con l'art. 4, comma 1) che "Fermo restando quanto previsto dall'articolo 3, le disposizioni degli articoli 1 e 2 non trovano applicazione nei rapporti disciplinati dalla legge 2 aprile 1958, n. 339. La disciplina di cui all'articolo 18 della legge 20 maggio 1970, n. 300, come modificato dall'articolo 1 della presente legge, non trova applicazione nei confronti dei datori di lavoro non imprenditori che svolgono senza fini di lucro attivita' di natura politica, sindacale, culturale, di istruzione ovvero di religione o di culto"; ha inoltre disposto (con l'art. 4, comma 2) che "Le disposizioni di cui all'articolo 18 della legge 20 maggio 1970, n. 300, come modificato dall'articolo 1 della presente legge, e dell'articolo 2 non si applicano nei confronti dei prestatori di lavoro ultrasessantenni, in possesso dei requisiti pensionistici, sempre che non abbiano optato per la prosecuzione del rapporto di lavoro ai sensi dell'articolo 6 del decreto-legge 22 dicembre 1981, n. 791, convertito, con modificazioni, dalla legge 26 febbraio 1982, n. 54. Sono fatte salve le disposizioni dell'articolo 3 della presente legge e dell'articolo 9 della legge 15 luglio 1966, n. 604". --------------- AGGIORNAMENTO (23) Il D.L. 31 dicembre 2007, n. 248, convertito con modificazioni dalla L. 28 febbraio 2008, n. 31, ha disposto (con l'art. 6, comma 2-bis) che "L'efficacia delle disposizioni di cui all'articolo 18 della legge 20 maggio 1970, n. 300, e successive modificazioni, nei confronti del prestatore di lavoro nelle condizioni previste dall'articolo 4, comma 2, della legge 11 maggio 1990, n. 108, e' comunque prorogata fino al momento della decorrenza del trattamento pensionistico di vecchiaia spettante al prestatore medesimo". --------------- AGGIORNAMENTO (28) La Corte Costituzionale, con sentenza 24 febbraio - 1 aprile 2021, n. 59 (in G.U. 1ª s.s. 07/04/2021, n. 14), ha dichiarato "l'illegittimita' costituzionale dell'art. 18, settimo comma, secondo periodo, della legge 20 maggio 1970, n. 300 (Norme sulla tutela della liberta' e dignita' dei lavoratori, della liberta' sindacale e dell'attivita' sindacale, nei luoghi di lavoro e norme sul collocamento), come modificato dall'art. 1, comma 42, lettera b), della legge 28 giugno 2012, n. 92 (Disposizioni in materia di riforma del mercato del lavoro in una prospettiva di crescita), nella parte in cui prevede che il giudice, quando accerti la manifesta insussistenza del fatto posto a base del licenziamento per giustificato motivo oggettivo, «puo' altresi' applicare» - invece che «applica altresi'» - la disciplina di cui al medesimo art. 18, quarto comma". --------------- AGGIORNAMENTO (30) La Corte Costituzionale, con sentenza 7 aprile - 19 maggio 2022, n. 125 (in G.U. 1ª s.s. 25/05/2022, n. 21), ha dichiarato "l'illegittimita' costituzionale dell'art. 18, settimo comma, secondo periodo, della legge 20 maggio 1970, n. 300 (Norme sulla tutela della liberta' e dignita' dei lavoratori, della liberta' sindacale e dell'attivita' sindacale nei luoghi di lavoro e norme sul collocamento), come modificato dall'art. 1, comma 42, lettera b), della legge 28 giugno 2012, n. 92 (Disposizioni in materia di riforma del mercato del lavoro in una prospettiva di crescita), limitatamente alla parola «manifesta»".

## DELL'ATTIVITA' SINDACALE

### Art. 19. - (Costituzione delle rappresentanze sindacali aziendali)

Rappresentanze sindacali aziendali possono essere costituite ad iniziativa dei lavoratori in ogni unita' produttiva, nell'ambito: a) LETTERA ABROGATA DAL D.P.R. 28 LUGLIO 1995, N. 312 A SEGUITO DI REFERENDUM POPOLARE. delle associazioni sindacali, che siano firmatarie di contratti collettivi di lavoro applicati nell'unita' produttiva. ((25)) Nell'ambito di aziende con piu' unita' produttive le rappresentanze sindacali possono istituire organi di coordinamento. (16)

------------- AGGIORNAMENTO (16) Il D.P.R. 28 luglio 1995, n. 312 ha disposto (con l'art. 1, comma 2) che l'abrogazione di cui alla lettera a) e l'abrogazione parziale di cui alla lettera b) del presente articolo hanno effetto decorsi sessanta giorni dalla data di pubblicazione del medesimo decreto nella Gazzetta Ufficiale. ------------- AGGIORNAMENTO (25) La Corte Costituzionale, con sentenza 3 - 23 luglio 2013, n. 231 (in G.U. 1a s.s. 31/7/2013, n. 31), ha dichiarato "l'illegittimita' costituzionale dell'articolo 19, primo comma, lettera b), della legge 20 maggio 1970, n. 300 (Norme sulla tutela della liberta' e dignita' dei lavoratori, della liberta' sindacale e dell'attivita' sindacale nei luoghi di lavoro e norme sul collocamento), nella parte in cui non prevede che la rappresentanza sindacale aziendale possa essere costituita anche nell'ambito di associazioni sindacali che, pur non firmatarie dei contratti collettivi applicati nell'unita' produttiva, abbiano comunque partecipato alla negoziazione relativa agli stessi contratti quali rappresentanti dei lavoratori dell'azienda".

### Art. 20. - (Assemblea)

I lavoratori hanno diritto di riunirsi, nella unita' produttiva in cui prestano la loro opera, fuori dell'orario di lavoro, nonche' durante l'orario di lavoro, nei limiti di dieci ore annue, per le quali verra' corrisposta la normale retribuzione. Migliori condizioni possono essere stabilite dalla contrattazione collettiva. Le riunioni - che possono riguardare la generalita' dei lavoratori o gruppi di essi - sono indette, singolarmente o congiuntamente, dalle rappresentanze sindacali aziendali nell'unita' produttiva, con ordine del giorno su materie di interesse sindacale e del lavoro e secondo l'ordine di precedenza delle convocazioni, comunicate al datore di lavoro. Alle riunioni possono partecipare, previo preavviso al datore di lavoro, dirigenti esterni del sindacato che ha costituito la rappresentanza sindacale aziendale. Ulteriori modalita' per l'esercizio del diritto di assemblea possono essere stabilite dai contratti collettivi di lavoro, anche aziendali.

### Art. 21. - (Referendum)

Il datore di lavoro deve consentire nell'ambito aziendale lo svolgimento, fuori dell'orario di lavoro, di referendum, sia generali che per categoria, su materie inerenti all'attivita' sindacale, indetti da tutte le rappresentanze sindacali aziendali tra i lavoratori, con diritto di partecipazione di tutti i lavoratori appartenenti alla unita' produttiva e alla categoria particolarmente interessata. Ulteriori modalita' per lo svolgimento del referendum possono essere stabilite dai contratti collettivi di lavoro anche aziendali.

### Art. 22. - (Trasferimento dei dirigenti delle rappresentanze sindacali aziendali)

Il trasferimento dall'unita' produttiva dei dirigenti delle rappresentanze sindacali aziendali di cui al precedente articolo 19, dei candidati e dei membri di commissione interna puo' essere disposto solo previo nulla osta delle associazioni sindacali di appartenenza. Le disposizioni di cui al comma precedente ed ai commi quarto, quinto, sesto e settimo dell'articolo 18 si applicano sino alla fine del terzo mese successivo a quello in cui e' stata eletta la commissione interna per i candidati nelle elezioni della commissione stessa e sino alla fine dell'anno successivo a quello in cui e' cessato l'incarico per tutti gli altri.

### Art. 23. - (Permessi retribuiti)

I dirigenti delle rappresentanze sindacali aziendali di cui all'articolo 19 hanno diritto, per l'espletamento del loro mandato, a permessi retribuiti. Salvo clausole piu' favorevoli dei contratti collettivi di lavoro hanno diritto ai permessi di cui al primo comma almeno: a) un dirigente per ciascuna rappresentanza sindacale aziendale nelle unita' produttive che occupano fino a 200 dipendenti della categoria per cui la stessa e' organizzata; b) un dirigente ogni 300 o frazione di 300 dipendenti per ciascuna rappresentanza sindacale aziendale nelle unita' produttive che occupano fino a 3.000 dipendenti della categoria per cui la stessa e' organizzata; c) un dirigente ogni 500 o frazione di 500 dipendenti della categoria per cui e' organizzata la rappresentanza sindacale aziendale nelle unita' produttive di maggiori dimensioni, in aggiunta al numero minimo di cui alla precedente lettera b). I permessi retribuiti di cui al presente articolo non potranno essere inferiori a otto ore mensili nelle aziende di cui alle lettere b) e c) del comma precedente; nelle aziende di cui alla lettera a) i permessi retribuiti non potranno essere inferiori ad un'ora all'anno per ciascun dipendente. Il lavoratore che intende esercitare il diritto di cui al primo comma deve darne comunicazione scritta al datore di lavoro di regola 24 ore prima, tramite le rappresentanze sindacali aziendali. ((1))

--------------- AGGIORNAMENTO (1) Il D.L. 2 marzo 1974, n. 30, convertito con modificazioni dalla L. 16 aprile 1974, n. 114, ha disposto (con l'art. 16-ter) che "I periodi di aspettativa previsti dall'articolo 31 della legge 20 maggio 1970, n. 300, e i permessi spettanti a norma degli articoli 23 e 32 della stessa legge, sono considerati come periodi di effettivo lavoro ai fini dell'applicazione delle norme sugli assegni familiari di cui al testo unico 30 maggio 1955, n. 797, o della corresponsione di altri trattamenti per i familiari a carico comunque denominati".

### Art. 24. - (Permessi non retribuiti)

I dirigenti sindacali aziendali di cui all'articolo 23 hanno diritto a permessi non retribuiti per la partecipazione a trattative sindacali o a congressi e convegni di natura sindacale, in misura non inferiore a otto giorni all'anno. I lavoratori che intendano esercitare il diritto di cui al comma precedente devono darne comunicazione scritta al datore di lavoro di regola tre giorni prima, tramite le rappresentanze sindacali aziendali.

### Art. 25. - (Diritto di affissione)

Le rappresentanze sindacali aziendali hanno diritto di affiggere, su appositi spazi, che il datore di lavoro ha l'obbligo di predisporre in luoghi accessibili a tutti i lavoratori all'interno dell'unita' produttiva, pubblicazioni, testi e comunicati inerenti a materie di interesse sindacale e del lavoro.

### Art. 26. - (Contributi sindacali)

I lavoratori hanno diritto di raccogliere contributi e di svolgere opera di proselitismo per le loro organizzazioni sindacali all'interno dei luoghi di lavoro, senza pregiudizio del normale svolgimento dell'attivita' aziendale. ((COMMA ABROGATO DAL D.P.R. 28 LUGLIO 1995, N. 313 A SEGUITO DI REFERENDUM POPOLARE)). ((COMMA ABROGATO DAL D.P.R. 28 LUGLIO 1995, N. 313 A SEGUITO DI REFERENDUM POPOLARE)).

### Art. 27. - (Locali delle rappresentanze sindacali aziendali)

Il datore di lavoro nelle unita' produttive con almeno 200 dipendenti pone permanentemente a disposizione delle rappresentanze sindacali aziendali, per l'esercizio delle loro funzioni, un idoneo locale comune all'interno della unita' produttiva o nelle immediate vicinanze di essa. Nelle unita' produttive con un numero inferiore di dipendenti le rappresentanze sindacali aziendali hanno diritto di usufruire, ove ne facciano richiesta, di un locale idoneo per le loro riunioni.

## DISPOSIZIONI VARIE E GENERALI

### Art. 28. - (Repressione della condotta antisindacale)

Qualora il datore di lavoro ponga in essere comportamenti diretti ad impedire o limitare l'esercizio della liberta' e della attivita' sindacale nonche' del diritto di sciopero, su ricorso degli organismi locali delle associazioni sindacali nazionali che vi abbiano interesse, il pretore del luogo ove e' posto in essere il comportamento denunziato, nei due giorni successivi, convocate le parti ed assunte sommarie informazioni, qualora ritenga sussistente la violazione di cui al presente comma, ordina al datore di lavoro, con decreto motivato ed immediatamente esecutivo, la cessazione del comportamento illegittimo e la rimozione degli effetti. L'efficacia esecutiva del decreto non puo' essere revocata fino alla sentenza con cui il pretore in funzione di giudice del lavoro definisce il giudizio instaurato a norma del comma successivo. Contro il decreto che decide sul ricorso e' ammessa, entro 15 giorni dalla comunicazione del decreto alle parti, opposizione davanti al pretore in funzione di giudice del lavoro che decide con sentenza immediatamente esecutiva. Si osservano le disposizioni degli articoli 413 e seguenti del codice di procedura civile. Il datore di lavoro che non ottempera al decreto, di cui al primo comma, o alla sentenza pronunciata nel giudizio di opposizione e' punito ai sensi dell'articolo 650 del codice penale. L'autorita' giudiziaria ordina la pubblicazione della sentenza penale di condanna nei modi stabiliti dall'articolo 36 del codice penale. ((COMMA ABROGATO DALLA L. 11 APRILE 2000, N. 83)). ((COMMA ABROGATO DALLA L. 11 APRILE 2000, N. 83)).

### Art. 29. - (Fusione delle rappresentanze sindacali aziendali)

Quando le rappresentanze sindacali aziendali di cui all'articolo 19 si siano costituite nell'ambito di due o piu' delle associazioni di cui alle lettere a) e b) del primo comma dell'articolo predetto, nonche' nella ipotesi di fusione di piu' rappresentanze sindacali, i limiti numerici stabiliti dall'articolo 23, secondo comma, si intendono riferiti a ciascuna delle associazioni sindacali unitariamente rappresentate nella unita' produttiva. Quando la formazione di rappresentanze sindacali unitarie consegua alla fusione delle associazioni di cui alle lettere a) e b) del primo comma dell'articolo 19, i limiti numerici della tutela accordata ai dirigenti di rappresentanze sindacali aziendali, stabiliti in applicazione dell'articolo 23, secondo comma, ovvero del primo comma del presente articolo restano immutati.

### Art. 30. - (Permessi per i dirigenti provinciali e nazionali)

I componenti degli organi direttivi, provinciali e nazionali, delle associazioni di cui all'articolo 19 hanno diritto a permessi retribuiti, secondo le norme dei contratti di lavoro, per la partecipazione alle riunioni degli organi suddetti.

### Art. 31. - Aspettativa dei lavoratori chiamati a funzioni pubbliche elettive o a ricoprire cariche sindacali provinciali e nazionali).

I lavoratori che siano eletti membri del Parlamento nazionale o del Parlamento europeo o di assemblee regionali ovvero siano chiamati ad altre funzioni pubbliche elettive possono, a richiesta, essere collocati in aspettativa non retribuita, per tutta la durata del loro mandato. La medesima disposizione si applica ai lavoratori chiamati a ricoprire cariche sindacali provinciali e nazionali. I periodi di aspettativa di cui ai precedenti commi sono considerati utili, a richiesta dell'interessato, ai fini del riconoscimento del diritto e della determinazione della misura della pensione a carico della assicurazione generale obbligatoria di cui al regio decreto-legge 4 ottobre 1935, n. 1827, e successive modifiche ed integrazioni, nonche' a carico di enti, fondi, casse e gestioni per forme obbligatorie di previdenza sostitutive della assicurazione predetta, o che ne comportino comunque l'esonero. Durante i periodi di aspettativa l'interessato, in caso di malattia, conserva il diritto alle prestazioni a carico dei competenti enti preposti alla erogazione delle prestazioni medesime. Le disposizioni di cui al terzo e al quarto comma non si applicano qualora a favore dei lavoratori siano previste forme previdenziali per il trattamento di pensione e per malattia, in relazione all'attivita' espletata durante il periodo di aspettativa. (1) ((15))

--------------- AGGIORNAMENTO (1) Il D.L. 2 marzo 1974, n. 30, convertito con modificazioni dalla L. 16 aprile 1974, n. 114, ha disposto (con l'art. 16-ter) che "I periodi di aspettativa previsti dall'articolo 31 della legge 20 maggio 1970, n. 300, e i permessi spettanti a norma degli articoli 23 e 32 della stessa legge, sono considerati come periodi di effettivo lavoro ai fini dell'applicazione delle norme sugli assegni familiari di cui al testo unico 30 maggio 1955, n. 797, o della corresponsione di altri trattamenti per i familiari a carico comunque denominati". --------------- AGGIORNAMENTO (15) La L. 23 dicembre 1994, n. 724 ha disposto (con l'art. 22, comma 39) che "La normativa prevista dall'articolo 31 della legge 20 maggio 1970, n. 300, e successive modificazioni, si interpreta autenticamente nel senso della sua applicabilita' ai dipendenti pubblici eletti nel Parlamento nazionale, nel Parlamento europeo e nei consigli regionali".

### Art. 32. - (Permessi ai lavoratori chiamati a funzioni pubbliche elettive)

I lavoratori eletti alla carica di consigliere comunale o provinciale che non chiedano di essere collocati in aspettativa sono, a loro richiesta, autorizzati ad assentarsi dal servizio per il tempo strettamente necessario all'espletamento del mandato, senza alcuna decurtazione della retribuzione. I lavoratori eletti alla carica di sindaco o di assessore comunale, ovvero di presidente di giunta provinciale o di assessore provinciale, hanno diritto anche a permessi non retribuiti per un minimo di trenta ore mensili. (1) ((6))

--------------- AGGIORNAMENTO (1) Il D.L. 2 marzo 1974, n. 30, convertito con modificazioni dalla L. 16 aprile 1974, n. 114, ha disposto (con l'art. 16-ter) che "I periodi di aspettativa previsti dall'articolo 31 della legge 20 maggio 1970, n. 300, e i permessi spettanti a norma degli articoli 23 e 32 della stessa legge, sono considerati come periodi di effettivo lavoro ai fini dell'applicazione delle norme sugli assegni familiari di cui al testo unico 30 maggio 1955, n. 797, o della corresponsione di altri trattamenti per i familiari a carico comunque denominati". --------------- AGGIORNAMENTO (6) La L. 27 dicembre 1985, n. 816 ha disposto (con l'art. 28, comma 1) che "Le disposizioni della presente legge sostituiscono le disposizioni contenute nell'articolo 32 della legge 20 maggio 1970, n. 300, quelle della legge 12 dicembre 1966, n. 1078, della legge 26 aprile 1974, n. 169, e della legge 18 dicembre 1979, n. 632, limitatamente a quanto espressamente disciplinato nella presente legge".

## NORME SUL COLLOCAMENTO

### Art. 33.

((ARTICOLO ABROGATO DAL D.LGS. 19 DICEMBRE 2002, N. 297))

### Art. 34.

((ARTICOLO ABROGATO DAL D.LGS. 19 DICEMBRE 2002, N. 297))

## DISPOSIZIONI FINALI E PENALI

### Art. 35. - (Campo di applicazione)

Per le imprese industriali e commerciali, le disposizioni del titolo III, ad eccezione del primo comma dell'articolo 27, della presente legge si applicano a ciascuna sede, stabilimento, filiale, ufficio o reparto autonomo che occupa piu' di quindici dipendenti. Le stesse disposizioni si applicano alle imprese agricole che occupano piu' di cinque dipendenti. Le norme suddette si applicano, altresi', alle imprese industriali e commerciali che nell'ambito dello stesso comune occupano piu' di quindici dipendenti ed alle imprese agricole che nel medesimo ambito territoriale occupano piu' di cinque dipendenti anche se ciascuna unita' produttiva, singolarmente considerata, non raggiunge tali limiti. Ferme restando le norme di cui agli articoli 1, 8, 9, 14, 15, 16 e 17, i contratti collettivi di lavoro provvedono ad applicare i principi di cui alla presente legge alle imprese di navigazione per il personale navigante. (7) (11) ((12))

--------------- AGGIORNAMENTO (7) La Corte Costituzionale, con sentenza del 26 marzo-3 aprile 1987, n. 96 (in G.U. 1a s.s. 08/04/1987, n. 15), ha dichiarato "la illegittimita' costituzionale dell'art. 35, terzo comma, della l. 20 maggio 1970, n. 300 (Norme sulla tutela della liberta' e dignita' dei lavoratori e dell'attivita' sindacale nei luoghi di lavoro e norme sul collocamento), nella parte in cui non prevede la diretta applicabilita' al predetto personale anche dell'art. 18 della stessa legge". --------------- AGGIORNAMENTO (11) La Corte Costituzionale, con sentenza del 17-31 gennaio 1991, n. 41 (in G.U. 1a s.s. 06/02/1991, n. 6), ha dichiarato "la illegittimita' costituzionale dell'art. 35, terzo comma, della legge 20 maggio 1970, n. 300 (Norme sulla tutela della liberta' e dignita' dei lavoratori e dell'attivita' sindacale nei luoghi di lavoro), nella parte in cui non prevede la diretta applicabilita' al predetto personale anche dell'art. 18 della stessa legge, come modificato dall'art. 1 della legge 11 maggio 1990, n. 108 (Disciplina dei licenziamenti individuali)". --------------- AGGIORNAMENTO (12) La Corte Costituzionale, con sentenza del 11-23 luglio 1991, n. 364 (in G.U. 1a s.s. 31/07/1991, n. 30), ha dichiarato "l'illegittimita' costituzionale dell'art. 35, terzo comma, della l. 20 maggio 1970, n. 300 (Norme sulla tutela della liberta' e dignita' dei lavoratori) nella parte in cui non prevede la diretta applicabilita' al personale navigante delle "imprese di navigazione" dei commi 1, 2 e 3 dell'art. 7 della medesima legge".

### Art. 36. - (Obblighi dei titolari di benefici accordati dallo Stato e degli appaltatori di opere pubbliche)

Nei provvedimenti di concessione di benefici accordati ai sensi delle vigenti leggi dallo Stato a favore di imprenditori che esercitano professionalmente un'attivita' economica organizzata e nei capitolati di appalto attinenti all'esecuzione di opere pubbliche, deve essere inserita la clausola esplicita determinante l'obbligo per il beneficiario o appaltatore di applicare o di far applicare nei confronti dei lavoratori dipendenti condizioni non inferiori a quelle risultanti dai contratti collettivi di lavoro della categoria e della zona. Tale obbligo deve essere osservato sia nella fase di realizzazione degli impianti o delle opere che in quella successiva, per tutto il tempo in cui l'imprenditore beneficia delle agevolazioni finanziarie e creditizie concesse dallo Stato ai sensi delle vigenti disposizioni di legge. Ogni infrazione al suddetto obbligo che sia accertata dall'Ispettorato del lavoro viene comunicata immediatamente ai Ministri nella cui amministrazione sia stata disposta la concessione del beneficio o dell'appalto. Questi adotteranno le opportune determinazioni, fino alla revoca del beneficio, e nei casi piu' gravi o nel caso di recidiva potranno decidere l'esclusione del responsabile, per un tempo fino a cinque anni, da qualsiasi ulteriore concessione di agevolazioni finanziarie o creditizie ovvero da qualsiasi appalto. Le disposizioni di cui ai commi precedenti si applicano anche quando si tratti di agevolazioni finanziarie o creditizie ovvero di appalti concessi da enti pubblici, ai quali l'Ispettorato del lavoro comunica direttamente le infrazioni per l'adozione delle sanzioni. ((18))

--------------- AGGIORNAMENTO (18) La Corte Costituzionale, con sentenza 1-19 giugno 1998, n. 226 (in G.U. 1a s.s. 24/06/1998, n. 25), ha dichiarato "l'illegittimita' costituzionale dell'art. 36 della legge 20 maggio 1970, n. 300 (Norme sulla tutela della liberta' e dignita' dei lavoratori, della liberta' sindacale e dell'attivita' sindacale nei luoghi di lavoro e norme sul collocamento), nella parte in cui non prevede che, nelle concessioni di pubblico servizio, deve essere inserita la clausola esplicita determinante l'obbligo per il concessionario di applicare o di far applicare nei confronti dei lavoratori dipendenti condizioni non inferiori a quelle risultanti dai contratti collettivi di lavoro della categoria e della zona".

### Art. 37. - (Applicazione ai dipendenti da enti pubblici)

Le disposizioni della presente legge si applicano anche ai rapporti di lavoro e di impiego dei dipendenti da enti pubblici che svolgono esclusivamente o prevalentemente attivita' economica. Le disposizioni della presente legge si applicano altresi' ai rapporti di impiego dei dipendenti dagli altri enti pubblici, salvo che la materia sia diversamente regolata da norme speciali.

### Art. 38. - (Disposizioni penali)

Le violazioni degli articoli 2, ((. . .)) 5, 6, ((. . .)) e 15, primo comma, lettera a), sono punite, salvo che il fatto non costituisca piu' grave reato, con l'ammenda da lire 100.000 a lire un milione o con l'arresto da 15 giorni ad un anno. Nei casi piu' gravi le pene dell'arresto e dell'ammenda sono applicate congiuntamente. Quando, per le condizioni economiche del reo, l'ammenda stabilita nel primo comma puo' presumersi inefficace anche se applicata nel massimo, il giudice ha facolta' di aumentarla fino al quintuplo. Nei casi previsti dal secondo comma, l'autorita' giudiziaria ordina la pubblicazione della sentenza penale di condanna nei modi stabiliti dall'articolo 36 del codice penale.

### Art. 39. - (Versamento delle ammende al Fondo adeguamento pensioni)

L'importo delle ammende e' versato al Fondo adeguamento pensioni dei lavoratori.

### Art. 40. - (Abrogazione delle disposizioni contrastanti)

Ogni disposizione in contrasto con le norme contenute nella presente legge e' abrogata. Restano salve le condizioni dei contratti collettivi e degli accordi sindacali piu' favorevoli ai lavoratori.

### Art. 41. - (Esenzioni fiscali)

Tutti gli atti e documenti necessari per la attuazione della presente legge e per l'esercizio dei diritti connessi, nonche' tutti gli atti e documenti relativi ai giudizi nascenti dalla sua applicazione sono esenti da bollo, imposte di registro o di qualsiasi altra specie e da tasse.

